@@ -43,7 +43,7 @@ class UDisksBackend(Backend):
                 break
             try:
                 device_i.FilesystemMount('', [])
-            except dbus.DBusException, e:
+            except dbus.DBusException as e:
                 if e._dbus_error_name != 'org.freedesktop.UDisks.Error.Busy':
                     raise
                 logging.debug('Busy.')
@@ -113,7 +113,7 @@ class UDisksBackend(Backend):
         if not get('device-is-mounted'):
             try:
                 mp = dk.FilesystemMount('', [], dbus_interface=DEVICE_IFACE)
-            except dbus.DBusException, e:
+            except dbus.DBusException as e:
                 logging.exception('Could not mount the device:')
                 return
         mount = get('device-mount-paths')[0]
