@@ -98,9 +98,11 @@ class GtkFrontend(Frontend):
         self.finished_exit.connect('clicked', lambda x: self.finished_dialog.hide())
         self.failed_exit.connect('clicked', lambda x: self.failed_exit.hide())
         self.progress_cancel_button.connect('clicked', lambda x: self.warning_dialog.show())
-        self.button_help.connect('clicked', lambda x: Gtk.show_uri(self.button_help.get_screen(),
-                                                                   'ghelp:usb-creator',
-                                                                   Gtk.get_current_event_time()))
+        # we currently do not have help
+        self.button_help.hide()
+        #self.button_help.connect('clicked', lambda x: Gtk.show_uri(self.button_help.get_screen(),
+        #                                                           'ghelp:usb-creator',
+        #                                                           Gtk.get_current_event_time()))
 
         def format_value(scale, value):
             return format_mb_size(value)
